Commit in slicPandora/src on MAIN
SimCalorimeterHitProcessor.cpp+4-41.28 -> 1.29
put back code for linking SimCalHit and CalHit readouts

slicPandora/src
SimCalorimeterHitProcessor.cpp 1.28 -> 1.29
diff -u -r1.28 -r1.29
--- SimCalorimeterHitProcessor.cpp	19 Sep 2011 20:34:53 -0000	1.28
+++ SimCalorimeterHitProcessor.cpp	17 Oct 2011 15:47:50 -0000	1.29
@@ -230,11 +230,11 @@
                 // Add the created CalorimeterHit to the collection.
                 calHits->addElement(calHit);
             }
-        }
 
-        // Set the ReadoutName parameter for LCSim to find the correct IDDecoder.
-        // FIXME Which name set here?
-        //calHits->parameters().setValue("ReadoutName", collectionName);
+            // Set the ReadoutName parameter for LCSim to find the correct IDDecoder.
+            // FIXME This should actually be in the outer loop but collectionName no longer available.
+            calHits->parameters().setValue("ReadoutName", collectionName);
+        }
 
         // Add the CalorimeterHits to the event with the collection name the same as the calorimeter type, e.g. EM_BARREL.
         event->addCollection(calHits, caloType);
CVSspam 0.2.8